@@ -39,6 +39,7 @@ mongoc_cmd_parts_init (mongoc_cmd_parts_t *parts,
    parts->is_write_command = false;
    parts->prohibit_lsid = false;
    parts->allow_txn_number = MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_UNKNOWN;
+   parts->is_retryable_read = false;
    parts->is_retryable_write = false;
    parts->has_temp_session = false;
    parts->client = client;
@@ -720,8 +721,42 @@ _is_retryable_write (const mongoc_cmd_parts_t *parts,
       return false;
    }
 
-   if (!mongoc_uri_get_option_as_bool (
-          parts->client->uri, MONGOC_URI_RETRYWRITES, false)) {
+   if (!mongoc_uri_get_option_as_bool (parts->client->uri,
+                                       MONGOC_URI_RETRYWRITES,
+                                       MONGOC_DEFAULT_RETRYWRITES)) {
+      return false;
+   }
+
+   return true;
+}
+
+
+/* Check if the read command should support retryable behavior. */
+bool
+_is_retryable_read (const mongoc_cmd_parts_t *parts,
+                    const mongoc_server_stream_t *server_stream)
+{
+   if (!parts->is_read_command) {
+      return false;
+   }
+
+   /* Commands that go through read_write_command helpers are also write
+    * commands. Prohibit from read retry. */
+   if (parts->is_write_command) {
+      return false;
+   }
+
+   if (server_stream->sd->max_wire_version < WIRE_VERSION_RETRY_READS) {
+      return false;
+   }
+
+   if (_mongoc_client_session_in_txn (parts->assembled.session)) {
+      return false;
+   }
+
+   if (!mongoc_uri_get_option_as_bool (parts->client->uri,
+                                       MONGOC_URI_RETRYREADS,
+                                       MONGOC_DEFAULT_RETRYREADS)) {
       return false;
    }
 
@@ -820,7 +855,10 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
                             "Read preference in a transaction must be primary");
             GOTO (done);
          }
-      } else if (!IS_PREF_PRIMARY (prefs_ptr)) {
+      } else if (!IS_PREF_PRIMARY (prefs_ptr) &&
+                 server_type != MONGOC_SERVER_STANDALONE) {
+         /* "Type Standalone: clients MUST NOT send the read preference to the
+          * server" */
          _mongoc_cmd_parts_add_read_prefs (&parts->extra, prefs_ptr);
       }
 
@@ -884,6 +922,11 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
          parts->is_retryable_write = true;
       }
 
+      /* Conversely, check if the command is retryable if it is a read. */
+      if (_is_retryable_read (parts, server_stream) && !is_get_more) {
+         parts->is_retryable_read = true;
+      }
+
       if (!bson_empty (&server_stream->cluster_time)) {
          cluster_time =
             _largest_cluster_time (&server_stream->cluster_time, cluster_time);
@@ -973,8 +1016,5 @@ mongoc_cmd_is_compressible (mongoc_cmd_t *cmd)
           !!strcasecmp (cmd->command_name, "saslstart") &&
           !!strcasecmp (cmd->command_name, "saslcontinue") &&
           !!strcasecmp (cmd->command_name, "createuser") &&
-          !!strcasecmp (cmd->command_name, "updateuser") &&
-          !!strcasecmp (cmd->command_name, "copydb") &&
-          !!strcasecmp (cmd->command_name, "copydbsaslstart") &&
-          !!strcasecmp (cmd->command_name, "copydbgetnonce");
+          !!strcasecmp (cmd->command_name, "updateuser");
 }
