@@ -30,6 +30,10 @@ _mongoc_host_list_push (const char *host,
                         int family,
                         mongoc_host_list_t *next);
 
+mongoc_host_list_t *
+_mongoc_host_list_copy (const mongoc_host_list_t *src,
+                        mongoc_host_list_t *next);
+
 bool
 _mongoc_host_list_from_string (mongoc_host_list_t *host_list,
                                const char *host_and_port);
@@ -49,6 +53,11 @@ bool
 _mongoc_host_list_equal (const mongoc_host_list_t *host_a,
                          const mongoc_host_list_t *host_b);
 
+void
+_mongoc_host_list_remove_host (mongoc_host_list_t **phosts,
+                               const char *host,
+                               uint16_t port);
+
 void
 _mongoc_host_list_destroy_all (mongoc_host_list_t *host);
 
