@@ -14,13 +14,11 @@
  * limitations under the License.
  */
 
+#include "mongoc/mongoc-prelude.h"
+
 #ifndef MONGOC_WRITE_COMMAND_PRIVATE_H
 #define MONGOC_WRITE_COMMAND_PRIVATE_H
 
-#if !defined(MONGOC_COMPILATION)
-#error "Only <mongoc/mongoc.h> can be included directly."
-#endif
-
 #include <bson/bson.h>
 
 #include "mongoc/mongoc-client.h"
@@ -39,6 +37,11 @@ struct _mongoc_crud_opts_t;
 #define MONGOC_WRITE_COMMAND_INSERT 1
 #define MONGOC_WRITE_COMMAND_UPDATE 2
 
+/* MongoDB has a extra allowance to allow updating 16mb document, as the update
+ * operators would otherwise overflow the 16mb object limit. See SERVER-10643
+ * for context. */
+#define BSON_OBJECT_ALLOWANCE (16 * 1024)
+
 struct _mongoc_bulk_write_flags_t {
    bool ordered;
    bool bypass_document_validation;
@@ -218,6 +221,11 @@ _mongoc_write_error_get_type (bool cmd_ret,
                               const bson_error_t *cmd_err,
                               const bson_t *reply);
 
+bool
+_mongoc_write_error_update_if_unsupported_storage_engine (bool cmd_ret,
+                                                          bson_error_t *cmd_err,
+                                                          bson_t *reply);
+
 BSON_END_DECLS
 
 
