@@ -76,6 +76,18 @@ test_conveniences_cleanup ()
 }
 
 
+void
+value_init_from_doc (bson_value_t *value, const bson_t *doc)
+{
+   BSON_ASSERT (doc);
+
+   value->value_type = BSON_TYPE_DOCUMENT;
+   value->value.v_doc.data = bson_malloc ((size_t) doc->len);
+   memcpy (value->value.v_doc.data, bson_get_data (doc), (size_t) doc->len);
+   value->value.v_doc.data_len = doc->len;
+}
+
+
 MONGOC_PRINTF_FORMAT (1, 2)
 bson_t *
 tmp_bson (const char *json, ...)
@@ -342,7 +354,8 @@ bson_lookup_write_concern (const bson_t *b, const char *key)
    }
 
    if (bson_has_field (&doc, "wtimeout")) {
-      mongoc_write_concern_set_wtimeout (wc, bson_lookup_int32 (&doc, "wtimeout"));
+      mongoc_write_concern_set_wtimeout_int64 (
+         wc, bson_lookup_int32 (&doc, "wtimeout"));
    }
 
    if (bson_has_field (&doc, "j")) {
@@ -487,6 +500,7 @@ bson_lookup_txn_opts (const bson_t *b, const char *key)
    mongoc_read_concern_t *rc;
    mongoc_write_concern_t *wc;
    mongoc_read_prefs_t *prefs;
+   int64_t max_commit_time_ms;
 
    bson_lookup_doc (b, key, &doc);
    opts = mongoc_transaction_opts_new ();
@@ -509,6 +523,11 @@ bson_lookup_txn_opts (const bson_t *b, const char *key)
       mongoc_read_prefs_destroy (prefs);
    }
 
+   if (bson_has_field (&doc, "maxCommitTimeMS")) {
+      max_commit_time_ms = bson_lookup_int32 (&doc, "maxCommitTimeMS");
+      mongoc_transaction_opts_set_max_commit_time_ms (opts, max_commit_time_ms);
+   }
+
    return opts;
 }
 
@@ -854,17 +873,12 @@ match_bson_with_ctx (const bson_t *doc, const bson_t *pattern, match_ctx_t *ctx)
       return true;
    }
 
-   if (bson_empty0 (doc)) {
-      /* non-empty pattern can't match doc */
-      match_err (ctx, "doc empty");
-      return false;
-   }
-
    BSON_ASSERT (bson_iter_init (&pattern_iter, pattern));
 
    while (bson_iter_next (&pattern_iter)) {
       key = bson_iter_key (&pattern_iter);
       value = bson_iter_value (&pattern_iter);
+
       found = find (&doc_iter,
                     doc,
                     key,
@@ -1190,7 +1204,8 @@ match_bson_value (const bson_value_t *doc,
       }
    }
 
-   if (is_number_type (pattern->value_type) && ctx &&
+   if (is_number_type (doc->value_type) &&
+       is_number_type (pattern->value_type) && ctx &&
        !ctx->strict_numeric_types) {
       doc_int64 = bson_value_as_int64 (doc);
       pattern_int64 = bson_value_as_int64 (pattern);
